@@ -10,6 +10,7 @@ from pokemontcgsdk.querybuilder import QueryBuilder
 from pokemontcgsdk.resistance import Resistance
 from pokemontcgsdk.set import Set
 from pokemontcgsdk.tcgplayer import TCGPlayer
+from pokemontcgsdk.cardmarket import Cardmarket
 from pokemontcgsdk.weakness import Weakness
 
 @dataclass
@@ -20,6 +21,7 @@ class Card():
     artist: Optional[str]
     ancientTrait: Optional[AncientTrait]
     attacks: Optional[List[Attack]]
+    cardmarket: Optional[Cardmarket]
     convertedRetreatCost: Optional[int]
     evolvesFrom: Optional[str]
     flavorText: Optional[str]
@@ -27,16 +29,18 @@ class Card():
     id: str
     images: CardImage
     legalities: Legality
+    regulationMark: Optional[str]
     name: str
     nationalPokedexNumbers: Optional[List[int]]
-    number: Optional[str]
+    number: str
     rarity: Optional[str]
+    regulationMark: Optional[str]
     resistances: Optional[List[Resistance]]
     retreatCost: Optional[List[str]]
     rules: Optional[List[str]]
     set: Set
     subtypes: Optional[List[str]]
-    supertype: Optional[str]
+    supertype: str
     tcgplayer: Optional[TCGPlayer]
     types: Optional[List[str]]
     weaknesses: Optional[List[Weakness]]
